BitField class abstract

An interface to prepare payload for decoding

Constructors

BitField()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convert64BitListTo8Bit(List<int> bitList) List<int>
Returns a list as byte level from bits
from(Uint8List bytes) List<int>
Returns a List as the bit level representation of the payload
getMapping(int length, int start, DBCSignalType signalType) List<int>
Returns a mapping to be used when decoding